@@ -33,9 +33,10 @@
 #  define KTEXTEDITOR_DEPRECATED_NO_EXPORT KTEXTEDITOR_NO_EXPORT KTEXTEDITOR_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KTEXTEDITOR_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KTEXTEDITOR_NO_DEPRECATED
+#    define KTEXTEDITOR_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
